@@ -29,8 +29,8 @@ requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
 logging.basicConfig(format=' %(message)s')
 
 
-netmiko_logger = logging.getLogger("paramiko")
-netmiko_logger.setLevel(logging.INFO)
+
+
 class dyagram:
 
     def __init__(self, inventory_file=None, verbose=False):
@@ -71,13 +71,13 @@ class dyagram:
 
 
     def setup_logging(self):
-        log = logging.getLogger("DYAGRAM")
-        log.setLevel(logging.INFO)
+        log = logging.getLogger("")
         self.log = log
         if self.verbose:
             self.log.setLevel(logging.INFO)
         else:
-            self.log.setLevel(logging.NOTSET)
+            self.log.setLevel(logging.CRITICAL)
+
 
 
     def get_current_site(self):
@@ -115,7 +115,6 @@ class dyagram:
         :return:
         """
 
-
         try:
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering LLDP Neighbors - START")
             resp = self._discover_lldp_neighbors_by_restconf(device)
@@ -929,7 +928,5 @@ def main():
 
 
 if __name__ == "__main__":
-    netmiko_logger = logging.getLogger("paramiko")
-    netmiko_logger.setLevel(logging.INFO)
     main()
 
